Documentation
¶
Overview ¶
Package build defines build target and build context structures
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( HostPlatform = label.Label("@bldy//platforms:host") DefaultPlatform = HostPlatform )
Functions ¶
This section is empty.
Types ¶
type Rule ¶
type Rule interface {
Name() string
Dependencies() []label.Label
Outputs() []string
Hash() []byte
Build(*executor.Executor) error
Platform() label.Label
Workspace() workspace.Workspace
}
Rule defines the interface that rules must implement for becoming build targets.
Source Files
¶
- build.go
- status_string.go
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
bldy
command
|
|
|
Package graph parses and generates build graphs
|
Package graph parses and generates build graphs |
|
Package internal is used for registering types in build, it had no clear place in other packages to go which is why it gets it's own package
|
Package internal is used for registering types in build, it had no clear place in other packages to go which is why it gets it's own package |
|
Package builder parses build graphs and coordinates builds
|
Package builder parses build graphs and coordinates builds |
|
Package racy deals with file cryptography
|
Package racy deals with file cryptography |
|
rules
|
|
|
Package integration only contains integration tests
|
Package integration only contains integration tests |
Click to show internal directories.
Click to hide internal directories.